@@ -301,6 +301,15 @@ impl BuildOptions {
                         if interpreter.is_empty() && !self.find_interpreter {
                             bail!("Couldn't find any python interpreters. Please specify at least one with -i");
                         }
+                        for interp in interpreter {
+                            // If `-i` looks like a file path, check if it's a valid interpreter
+                            if interp.components().count() > 1
+                                && PythonInterpreter::check_executable(interp, target, bridge)?
+                                    .is_none()
+                            {
+                                bail!("{} is not a valid python interpreter", interp.display());
+                            }
+                        }
                         interpreters =
                             find_interpreter_in_sysconfig(interpreter, target, min_python_minor)?;
                     }
@@ -507,6 +516,12 @@ impl BuildOptions {
         let mut target_triple = self.target.clone();
 
         let mut universal2 = self.universal2;
+        if universal2 {
+            eprintln!("⚠️  Warning: `--universal2` is deprecated, use `--target univeral2-apple-darwin` instead");
+        } else if target_triple.as_deref() == Some("universal2-apple-darwin") {
+            universal2 = true;
+            target_triple = None;
+        }
         // Also try to determine universal2 from ARCHFLAGS environment variable
         if let Ok(arch_flags) = env::var("ARCHFLAGS") {
             let arches: HashSet<&str> = arch_flags
@@ -914,7 +929,7 @@ pub fn find_bridge(cargo_metadata: &Metadata, bridge: Option<&str>) -> Result<Br
     };
 
     if !(bridge.is_bindings("pyo3") || bridge.is_bindings("pyo3-ffi")) {
-        println!("🔗 Found {bridge} bindings");
+        eprintln!("🔗 Found {bridge} bindings");
     }
 
     for &lib in PYO3_BINDING_CRATES.iter() {
@@ -930,10 +945,10 @@ pub fn find_bridge(cargo_metadata: &Metadata, bridge: Option<&str>) -> Result<Br
             }
 
             return if let Some((major, minor)) = has_abi3(cargo_metadata)? {
-                println!("🔗 Found {lib} bindings with abi3 support for Python ≥ {major}.{minor}");
+                eprintln!("🔗 Found {lib} bindings with abi3 support for Python ≥ {major}.{minor}");
                 Ok(BridgeModel::BindingsAbi3(major, minor))
             } else {
-                println!("🔗 Found {lib} bindings");
+                eprintln!("🔗 Found {lib} bindings");
                 Ok(bridge)
             };
         }
