@@ -7,14 +7,15 @@ use anyhow::{bail, Context, Result};
 use cargo_zigbuild::Zig;
 use clap::{CommandFactory, Parser, Subcommand};
 use maturin::{
-    develop, init_project, new_project, write_dist_info, BridgeModel, BuildOptions, CargoOptions,
-    GenerateProjectOptions, PathWriter, PlatformTag, PythonInterpreter, Target,
+    ci::GenerateCI, develop, init_project, new_project, write_dist_info, BridgeModel, BuildOptions,
+    CargoOptions, GenerateProjectOptions, PathWriter, PlatformTag, PythonInterpreter, Target,
 };
 #[cfg(feature = "upload")]
 use maturin::{upload_ui, PublishOpt};
 use std::env;
 use std::io;
 use std::path::PathBuf;
+use tracing::debug;
 
 #[derive(Debug, Parser)]
 #[command(
@@ -129,6 +130,8 @@ enum Opt {
         #[command(flatten)]
         options: GenerateProjectOptions,
     },
+    #[command(name = "generate-ci")]
+    GenerateCI(GenerateCI),
     /// Upload python packages to pypi
     ///
     /// It is mostly similar to `twine upload`, but can only upload python wheels
@@ -202,6 +205,52 @@ enum Pep517Command {
     },
 }
 
+fn detect_venv(target: &Target) -> Result<PathBuf> {
+    match (env::var_os("VIRTUAL_ENV"), env::var_os("CONDA_PREFIX")) {
+        (Some(dir), None) => return Ok(PathBuf::from(dir)),
+        (None, Some(dir)) => return Ok(PathBuf::from(dir)),
+        (Some(_), Some(_)) => {
+            bail!("Both VIRTUAL_ENV and CONDA_PREFIX are set. Please unset one of them")
+        }
+        (None, None) => {
+            // No env var, try finding .venv
+        }
+    };
+
+    let current_dir = env::current_dir().context("Failed to detect current directory ಠ_ಠ")?;
+    // .venv in the current or any parent directory
+    for dir in current_dir.ancestors() {
+        let dot_venv = dir.join(".venv");
+        if dot_venv.is_dir() {
+            if !dot_venv.join("pyvenv.cfg").is_file() {
+                bail!(
+                    "Expected {} to be a virtual environment, but pyvenv.cfg is missing",
+                    dot_venv.display()
+                );
+            }
+            let python = target.get_venv_python(&dot_venv);
+            if !python.is_file() {
+                bail!(
+                    "Your virtualenv at {} is broken. It contains a pyvenv.cfg but no python at {}",
+                    dot_venv.display(),
+                    python.display()
+                );
+            }
+            debug!("Found a virtualenv named .venv at {}", dot_venv.display());
+            return Ok(dot_venv);
+        }
+    }
+
+    bail!(
+        "Couldn't find a virtualenv or conda environment, but you need one to use this command. \
+        For maturin to find your virtualenv you need to either set VIRTUAL_ENV (through activate), \
+        set CONDA_PREFIX (through conda activate) or have a virtualenv called .venv in the current \
+        or any parent folder. \
+        See https://virtualenv.pypa.io/en/latest/index.html on how to use virtualenv or \
+        use `maturin build` and `pip install <path/to/wheel>` instead."
+    )
+}
+
 /// Dispatches into the native implementations of the PEP 517 functions
 ///
 /// The last line of stdout is used as return value from the python part of the implementation
@@ -356,22 +405,8 @@ fn run() -> Result<()> {
             extras,
             cargo_options,
         } => {
-            let venv_dir = match (env::var_os("VIRTUAL_ENV"), env::var_os("CONDA_PREFIX")) {
-                (Some(dir), None) => PathBuf::from(dir),
-                (None, Some(dir)) => PathBuf::from(dir),
-                (Some(_), Some(_)) => {
-                    bail!("Both VIRTUAL_ENV and CONDA_PREFIX are set. Please unset one of them")
-                }
-                (None, None) => {
-                    bail!(
-                        "You need to be inside a virtualenv or conda environment to use develop \
-                        (neither VIRTUAL_ENV nor CONDA_PREFIX are set). \
-                        See https://virtualenv.pypa.io/en/latest/index.html on how to use virtualenv or \
-                        use `maturin build` and `pip install <path/to/wheel>` instead."
-                    )
-                }
-            };
-
+            let target = Target::from_target_triple(cargo_options.target.clone())?;
+            let venv_dir = detect_venv(&target)?;
             develop(bindings, cargo_options, &venv_dir, release, strip, extras)?;
         }
         Opt::SDist { manifest_path, out } => {
@@ -391,6 +426,7 @@ fn run() -> Result<()> {
         Opt::Pep517(subcommand) => pep517(subcommand)?,
         Opt::InitProject { path, options } => init_project(path, options)?,
         Opt::NewProject { path, options } => new_project(path, options)?,
+        Opt::GenerateCI(generate_ci) => generate_ci.execute()?,
         #[cfg(feature = "upload")]
         Opt::Upload { publish, files } => {
             if files.is_empty() {
