@@ -23,7 +23,7 @@ pub struct WheelMetadata {
 
 /// Python Package Metadata 2.1 as specified in
 /// https://packaging.python.org/specifications/core-metadata/
-#[derive(Serialize, Deserialize, Debug, Clone, Eq, PartialEq)]
+#[derive(Serialize, Deserialize, Debug, Default, Clone, Eq, PartialEq)]
 #[serde(rename_all = "kebab-case")]
 #[allow(missing_docs)]
 pub struct Metadata21 {
@@ -180,7 +180,7 @@ impl Metadata21 {
                 for author in authors {
                     match (&author.name, &author.email) {
                         (Some(name), Some(email)) => {
-                            emails.push(format!("{} <{}>", name, email));
+                            emails.push(format!("{name} <{email}>"));
                         }
                         (Some(name), None) => {
                             names.push(name.as_str());
@@ -205,7 +205,7 @@ impl Metadata21 {
                 for maintainer in maintainers {
                     match (&maintainer.name, &maintainer.email) {
                         (Some(name), Some(email)) => {
-                            emails.push(format!("{} <{}>", name, email));
+                            emails.push(format!("{name} <{email}>"));
                         }
                         (Some(name), None) => {
                             names.push(name.as_str());
@@ -248,9 +248,9 @@ impl Metadata21 {
                             // optional dependency already has environment markers
                             let new_marker =
                                 format!("({}) and extra == '{}'", marker.trim(), extra);
-                            format!("{}; {}", dep, new_marker)
+                            format!("{dep}; {new_marker}")
                         } else {
-                            format!("{}; extra == '{}'", dep, extra)
+                            format!("{dep}; extra == '{extra}'")
                         };
                         self.requires_dist.push(dist);
                     }
@@ -289,9 +289,6 @@ impl Metadata21 {
             .root_package()
             .context("Expected cargo to return metadata with root_package")?;
         let authors = package.authors.join(", ");
-
-        let classifiers = cargo_toml.classifiers();
-
         let author_email = if authors.contains('@') {
             Some(authors.clone())
         } else {
@@ -313,9 +310,7 @@ impl Metadata21 {
                 readme_path.display()
             ))?);
 
-            description_content_type = extra_metadata
-                .description_content_type
-                .or_else(|| Some(path_to_content_type(&readme_path)));
+            description_content_type = Some(path_to_content_type(&readme_path));
         } else {
             // > If no value is specified for this field, and a file named
             // > README.md, README.txt or README exists in the package root
@@ -344,10 +339,15 @@ impl Metadata21 {
                 }
             })
             .unwrap_or_else(|| package.name.clone());
-        let mut project_url = extra_metadata.project_url.unwrap_or_default();
+        let mut project_url = HashMap::new();
         if let Some(repository) = package.repository.as_ref() {
             project_url.insert("Source Code".to_string(), repository.clone());
         }
+        let license_files = if let Some(license_file) = package.license_file.as_ref() {
+            vec![manifest_path.as_ref().join(license_file)]
+        } else {
+            Vec::new()
+        };
 
         let metadata = Metadata21 {
             metadata_version: "2.1".to_owned(),
@@ -373,28 +373,9 @@ impl Metadata21 {
             },
             author_email,
             license: package.license.clone(),
-            license_files: Vec::new(),
-
-            // Values provided through `[project.metadata.maturin]`
-            classifiers,
-            maintainer: extra_metadata.maintainer,
-            maintainer_email: extra_metadata.maintainer_email,
-            requires_dist: extra_metadata.requires_dist.unwrap_or_default(),
-            requires_python: extra_metadata.requires_python,
-            requires_external: extra_metadata.requires_external.unwrap_or_default(),
+            license_files,
             project_url,
-            provides_extra: extra_metadata.provides_extra.unwrap_or_default(),
-
-            // Officially rarely used, and afaik not applicable with pyo3
-            provides_dist: Vec::new(),
-            obsoletes_dist: Vec::new(),
-
-            // Open question: Should those also be supported? And if so, how?
-            platform: Vec::new(),
-            supported_platform: Vec::new(),
-            scripts: cargo_toml.scripts(),
-            gui_scripts: HashMap::new(),
-            entry_points: HashMap::new(),
+            ..Default::default()
         };
         Ok(metadata)
     }
@@ -452,7 +433,7 @@ impl Metadata21 {
         // "A string containing a browsable URL for the project and a label for it, separated by a comma."
         // `Project-URL: Bug Tracker, http://bitbucket.org/tarek/distribute/issues/`
         for (key, value) in self.project_url.iter() {
-            fields.push(("Project-URL", format!("{}, {}", key, value)))
+            fields.push(("Project-URL", format!("{key}, {value}")))
         }
 
         // Description shall be last, so we can ignore RFC822 and just put the description
@@ -483,11 +464,11 @@ impl Metadata21 {
         };
 
         for (key, value) in fields {
-            writeln!(out, "{}: {}", key, value)?;
+            writeln!(out, "{key}: {value}")?;
         }
 
         if let Some(body) = body {
-            writeln!(out, "\n{}", body)?;
+            writeln!(out, "\n{body}")?;
         }
 
         Ok(out)
@@ -643,14 +624,6 @@ mod test {
             [lib]
             crate-type = ["cdylib"]
             name = "pyo3_pure"
-
-            [package.metadata.maturin.scripts]
-            ph = "maturin:print_hello"
-
-            [package.metadata.maturin]
-            classifiers = ["Programming Language :: Python"]
-            requires-dist = ["flask~=1.1.0", "toml==0.10.0"]
-            project-url = { "Bug Tracker" = "http://bitbucket.org/tarek/distribute/issues/" }
         "#
         );
 
@@ -659,16 +632,12 @@ mod test {
             Metadata-Version: 2.1
             Name: info-project
             Version: 0.1.0
-            Classifier: Programming Language :: Python
-            Requires-Dist: flask~=1.1.0
-            Requires-Dist: toml==0.10.0
             Summary: A test project
             Keywords: ffi,test
             Home-Page: https://example.org
             Author: konstin <konstin@mailbox.org>
             Author-email: konstin <konstin@mailbox.org>
             Description-Content-Type: text/markdown; charset=UTF-8; variant=GFM
-            Project-URL: Bug Tracker, http://bitbucket.org/tarek/distribute/issues/
 
             # Some test package
 
@@ -679,65 +648,6 @@ mod test {
         assert_metadata_from_cargo_toml(readme, cargo_toml, expected);
     }
 
-    #[test]
-    fn test_metadata_from_cargo_toml_rst() {
-        let readme = indoc!(
-            r#"
-            Some test package
-            =================
-        "#
-        );
-
-        let cargo_toml = indoc!(
-            r#"
-            [package]
-            authors = ["konstin <konstin@mailbox.org>"]
-            name = "info-project"
-            version = "0.1.0"
-            description = "A test project"
-            homepage = "https://example.org"
-            repository = "https://example.org"
-            readme = "REPLACE_README_PATH"
-            keywords = ["ffi", "test"]
-
-            [lib]
-            crate-type = ["cdylib"]
-            name = "pyo3_pure"
-
-            [package.metadata.maturin.scripts]
-            ph = "maturin:print_hello"
-
-            [package.metadata.maturin]
-            classifiers = ["Programming Language :: Python"]
-            requires-dist = ["flask~=1.1.0", "toml==0.10.0"]
-            description-content-type = "text/x-rst"
-        "#
-        );
-
-        let expected = indoc!(
-            r#"
-            Metadata-Version: 2.1
-            Name: info-project
-            Version: 0.1.0
-            Classifier: Programming Language :: Python
-            Requires-Dist: flask~=1.1.0
-            Requires-Dist: toml==0.10.0
-            Summary: A test project
-            Keywords: ffi,test
-            Home-Page: https://example.org
-            Author: konstin <konstin@mailbox.org>
-            Author-email: konstin <konstin@mailbox.org>
-            Description-Content-Type: text/x-rst
-            Project-URL: Source Code, https://example.org
-
-            Some test package
-            =================
-        "#
-        );
-
-        assert_metadata_from_cargo_toml(readme, cargo_toml, expected);
-    }
-
     #[test]
     fn test_metadata_from_cargo_toml_name_override() {
         let readme = indoc!(
@@ -761,13 +671,8 @@ mod test {
             crate-type = ["cdylib"]
             name = "pyo3_pure"
 
-            [package.metadata.maturin.scripts]
-            ph = "maturin:print_hello"
-
             [package.metadata.maturin]
             name = "info"
-            classifiers = ["Programming Language :: Python"]
-            description-content-type = "text/x-rst"
         "#
         );
 
@@ -776,12 +681,11 @@ mod test {
             Metadata-Version: 2.1
             Name: info
             Version: 0.1.0
-            Classifier: Programming Language :: Python
             Summary: A test project
             Home-Page: https://example.org
             Author: konstin <konstin@mailbox.org>
             Author-email: konstin <konstin@mailbox.org>
-            Description-Content-Type: text/x-rst
+            Description-Content-Type: text/markdown; charset=UTF-8; variant=GFM
 
             Some test package
             =================
@@ -840,7 +744,7 @@ mod test {
         );
         assert_eq!(
             metadata.description,
-            Some(fs_err::read_to_string("test-crates/pyo3-pure/Readme.md").unwrap())
+            Some(fs_err::read_to_string("test-crates/pyo3-pure/README.md").unwrap())
         );
         assert_eq!(metadata.classifiers, &["Programming Language :: Rust"]);
         assert_eq!(
@@ -915,7 +819,7 @@ mod test {
     #[test]
     fn test_merge_metadata_from_pyproject_dynamic_license_test() {
         let manifest_dir = PathBuf::from("test-crates").join("license-test");
-        let cargo_toml_str = fs_err::read_to_string(&manifest_dir.join("Cargo.toml")).unwrap();
+        let cargo_toml_str = fs_err::read_to_string(manifest_dir.join("Cargo.toml")).unwrap();
         let cargo_toml: CargoToml = toml_edit::easy::from_str(&cargo_toml_str).unwrap();
         let cargo_metadata = MetadataCommand::new()
             .manifest_path(manifest_dir.join("Cargo.toml"))
