@@ -85,7 +85,7 @@ impl ProjectResolver {
         cargo_options.manifest_path = Some(manifest_file.clone());
 
         let cargo_toml = CargoToml::from_path(&manifest_file)?;
-        cargo_toml.warn_removed_python_metadata();
+        cargo_toml.check_removed_python_metadata()?;
 
         let manifest_dir = manifest_file.parent().unwrap();
         let pyproject_toml: Option<PyProjectToml> = if pyproject_file.is_file() {
@@ -400,7 +400,7 @@ impl ProjectLayout {
                 bail!("Found a directory with the module name ({}) next to Cargo.toml, which indicates a mixed python/rust project, but the directory didn't contain an __init__.py file.", module_name)
             }
 
-            println!("🍹 Building a mixed python/rust project");
+            eprintln!("🍹 Building a mixed python/rust project");
 
             Ok(ProjectLayout {
                 python_dir: python_root,
